# MATER data providing

A library to help providing the right json files to feed the mater database.

It can be used to create a local json database to run mater simulations locally.

[TOC]

## 📋 Requirements

- Python 3.12 or higher

We recommend using one virtual environment per Python project to manage dependencies and maintain isolation. You can use a package manager like [uv](https://docs.astral.sh/uv/) to help you with library dependencies and virtual environments.

## 📦 Install the mater-data-providing Package

Install the `mater-data-providing` package via uv (recomanded):

```bash
uv add mater-data-providing
```

Install the `mater-data-providing` package via pip:

```bash
pip install mater-data-providing
```

## 📚 Getting started

To get started, refer to the official **[documentation](https://isterre-dynamic-modeling.gricad-pages.univ-grenoble-alpes.fr/mater-project/data-providing)**.
